@@ -29,6 +29,10 @@ DEFAULT_OPTIONS = {
         'log_config_file': None
     },
     'table': {
+        'reads-upper-alarm-threshold': 0,
+        'reads-lower-alarm-threshold': 0,
+        'writes-upper-alarm-threshold': 0,
+        'writes-lower-alarm-threshold': 0,
         'enable_reads_autoscaling': True,
         'enable_writes_autoscaling': True,
         'reads_lower_threshold': 30,
@@ -61,6 +65,10 @@ DEFAULT_OPTIONS = {
         'sns_message_types': []
     },
     'gsi': {
+        'reads-upper-alarm-threshold': 0,
+        'reads-lower-alarm-threshold': 0,
+        'writes-upper-alarm-threshold': 0,
+        'writes-lower-alarm-threshold': 0,
         'enable_reads_autoscaling': True,
         'enable_writes_autoscaling': True,
         'reads_lower_threshold': 30,
@@ -329,7 +337,7 @@ def __check_gsi_rules(configuration):
                 gsi['increase_reads_with'] = 100
 
             # Check sns-message-types
-            valid_sns_message_types = ['scale-up', 'scale-down']
+            valid_sns_message_types = ['scale-up', 'scale-down', 'high-throughput-alarm', 'low-throughput-alarm']
             if gsi['sns_message_types']:
                 for sns_type in gsi['sns_message_types']:
                     if sns_type not in valid_sns_message_types:
@@ -414,7 +422,7 @@ def __check_table_rules(configuration):
             sys.exit(1)
 
         # Check sns-message-types
-        valid_sns_message_types = ['scale-up', 'scale-down']
+        valid_sns_message_types = ['scale-up', 'scale-down', 'high-throughput-alarm', 'low-throughput-alarm']
         if table['sns_message_types']:
             for sns_type in table['sns_message_types']:
                 if sns_type not in valid_sns_message_types:
